@@ -69,7 +69,8 @@ class LuksEncryptor(cryptsetup.CryptsetupEncryptor):
 
         # NOTE(joel-coffman): cryptsetup will strip trailing newlines from
         # input specified on stdin unless --key-file=- is specified.
-        cmd = ["cryptsetup", "--batch-mode", "luksFormat", "--key-file=-"]
+        cmd = ["cryptsetup", "--batch-mode", "luksFormat", "--type", "luks1",
+               "--key-file=-"]
 
         cipher = kwargs.get("cipher", None)
         if cipher is not None:
@@ -118,7 +119,6 @@ class LuksEncryptor(cryptsetup.CryptsetupEncryptor):
         # Enter new passphrase for key slot:
         # Verify passphrase:
         self._execute('cryptsetup', 'luksAddKey', self.dev_path,
-                      '--force-password',
                       process_input=''.join([mangled_passphrase, '\n',
                                              passphrase, '\n', passphrase]),
                       run_as_root=True, check_exit_code=True,
